==> haskell-magic-1.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-magic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 magic
version:              1.1
visibility:           public
id:                   magic-1.1-DuzIDA56MgBCnBWrbzXtOB
key:                  magic-1.1-DuzIDA56MgBCnBWrbzXtOB
license:              BSD-3-Clause
copyright:            Copyright (c) 2005-2009 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Alpha
synopsis:             Interface to C file/magic library
description:
    This package provides a Haskell interface to the C libmagic library.
    With it, you can determine the type of a file by examining its contents
    rather than its name.  The Haskell interface provides a full-featured
    binding.

category:             Text
abi:                  c2b81c8cbac1b026ca3a73995df6f47f
exposed:              True
exposed-modules:
    Magic Magic.Data Magic.Init Magic.Operations Magic.Types

hidden-modules:       Magic.Utils Magic.TypesLL
import-dirs:          /usr/lib/ghc-9.0.2/site-local/magic-1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/magic-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/magic-1.1
hs-libraries:         HSmagic-1.1-DuzIDA56MgBCnBWrbzXtOB
extra-libraries:      magic
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-magic/html/magic.haddock
haddock-html:         /usr/share/doc/haskell-magic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-magic-1.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-magic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 magic
version:              1.1
visibility:           public
id:                   magic-1.1-JXc9Avtt6LaG2VzhwxObOv
key:                  magic-1.1-JXc9Avtt6LaG2VzhwxObOv
license:              BSD-3-Clause
copyright:            Copyright (c) 2005-2009 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Alpha
synopsis:             Interface to C file/magic library
description:
    This package provides a Haskell interface to the C libmagic library.
    With it, you can determine the type of a file by examining its contents
    rather than its name.  The Haskell interface provides a full-featured
    binding.

category:             Text
abi:                  540807a513e5ed18e8cef6386d9f584b
exposed:              True
exposed-modules:
    Magic Magic.Data Magic.Init Magic.Operations Magic.Types

hidden-modules:       Magic.Utils Magic.TypesLL
import-dirs:          /usr/lib/ghc-9.2.8/site-local/magic-1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/magic-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-magic
hs-libraries:         HSmagic-1.1-JXc9Avtt6LaG2VzhwxObOv
extra-libraries:      magic
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-magic/html/magic.haddock
haddock-html:         /usr/share/doc/haskell-magic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
